CertaboCommunicationClient class

Constructors

CertaboCommunicationClient(CertaboConnectionType connectionType, Future<void> send(Uint8List))

Properties

connectionType → CertaboConnectionType
final
hashCode → int
The hash code for this object.
no setterinherited
receiveStream → Stream<Uint8List>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
send → Future<void> Function(Uint8List)
final

Methods

handleReceive(Uint8List message) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited